.. easy-slam documentation master file

Welcome to easy-slam's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules

Introduction
------------

**easy-slam** is a beginner-friendly yet powerful SLAM library for robotics and research.

API Reference
-------------

.. automodule:: easy_slam
    :members:
    :undoc-members:
    :show-inheritance: 